@@ -3,8 +3,11 @@ Main interface for logs service client paginators.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.logs import (
+
+    from mypy_boto3_logs import CloudWatchLogsClient
+    from mypy_boto3_logs import (
         DescribeDestinationsPaginator,
         DescribeExportTasksPaginator,
         DescribeLogGroupsPaginator,
@@ -27,10 +30,11 @@ Usage::
     describe_resource_policies_paginator: DescribeResourcePoliciesPaginator = client.get_paginator("describe_resource_policies")
     describe_subscription_filters_paginator: DescribeSubscriptionFiltersPaginator = client.get_paginator("describe_subscription_filters")
     filter_log_events_paginator: FilterLogEventsPaginator = client.get_paginator("filter_log_events")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import Generator, List, TYPE_CHECKING
+from typing import Iterator, List, TYPE_CHECKING
 from botocore.paginate import Paginator as Boto3Paginator
 from mypy_boto3_logs.type_defs import (
     DescribeDestinationsResponseTypeDef,
@@ -66,20 +70,20 @@ __all__ = (
 
 class DescribeDestinationsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeDestinations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.4/reference/services/logs.html#CloudWatchLogs.Paginator.DescribeDestinations)
+    [Paginator.DescribeDestinations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/logs.html#CloudWatchLogs.Paginator.DescribeDestinations)
     """
 
     def paginate(
         self, DestinationNamePrefix: str = None, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[DescribeDestinationsResponseTypeDef, None, None]:
+    ) -> Iterator[DescribeDestinationsResponseTypeDef]:
         """
-        [DescribeDestinations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.4/reference/services/logs.html#CloudWatchLogs.Paginator.DescribeDestinations.paginate)
+        [DescribeDestinations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/logs.html#CloudWatchLogs.Paginator.DescribeDestinations.paginate)
         """
 
 
 class DescribeExportTasksPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeExportTasks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.4/reference/services/logs.html#CloudWatchLogs.Paginator.DescribeExportTasks)
+    [Paginator.DescribeExportTasks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/logs.html#CloudWatchLogs.Paginator.DescribeExportTasks)
     """
 
     def paginate(
@@ -89,28 +93,28 @@ class DescribeExportTasksPaginator(Boto3Paginator):
             "CANCELLED", "COMPLETED", "FAILED", "PENDING", "PENDING_CANCEL", "RUNNING"
         ] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DescribeExportTasksResponseTypeDef, None, None]:
+    ) -> Iterator[DescribeExportTasksResponseTypeDef]:
         """
-        [DescribeExportTasks.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.4/reference/services/logs.html#CloudWatchLogs.Paginator.DescribeExportTasks.paginate)
+        [DescribeExportTasks.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/logs.html#CloudWatchLogs.Paginator.DescribeExportTasks.paginate)
         """
 
 
 class DescribeLogGroupsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeLogGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.4/reference/services/logs.html#CloudWatchLogs.Paginator.DescribeLogGroups)
+    [Paginator.DescribeLogGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/logs.html#CloudWatchLogs.Paginator.DescribeLogGroups)
     """
 
     def paginate(
         self, logGroupNamePrefix: str = None, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[DescribeLogGroupsResponseTypeDef, None, None]:
+    ) -> Iterator[DescribeLogGroupsResponseTypeDef]:
         """
-        [DescribeLogGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.4/reference/services/logs.html#CloudWatchLogs.Paginator.DescribeLogGroups.paginate)
+        [DescribeLogGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/logs.html#CloudWatchLogs.Paginator.DescribeLogGroups.paginate)
         """
 
 
 class DescribeLogStreamsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeLogStreams documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.4/reference/services/logs.html#CloudWatchLogs.Paginator.DescribeLogStreams)
+    [Paginator.DescribeLogStreams documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/logs.html#CloudWatchLogs.Paginator.DescribeLogStreams)
     """
 
     def paginate(
@@ -120,15 +124,15 @@ class DescribeLogStreamsPaginator(Boto3Paginator):
         orderBy: Literal["LogStreamName", "LastEventTime"] = None,
         descending: bool = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DescribeLogStreamsResponseTypeDef, None, None]:
+    ) -> Iterator[DescribeLogStreamsResponseTypeDef]:
         """
-        [DescribeLogStreams.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.4/reference/services/logs.html#CloudWatchLogs.Paginator.DescribeLogStreams.paginate)
+        [DescribeLogStreams.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/logs.html#CloudWatchLogs.Paginator.DescribeLogStreams.paginate)
         """
 
 
 class DescribeMetricFiltersPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeMetricFilters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.4/reference/services/logs.html#CloudWatchLogs.Paginator.DescribeMetricFilters)
+    [Paginator.DescribeMetricFilters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/logs.html#CloudWatchLogs.Paginator.DescribeMetricFilters)
     """
 
     def paginate(
@@ -138,15 +142,15 @@ class DescribeMetricFiltersPaginator(Boto3Paginator):
         metricName: str = None,
         metricNamespace: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DescribeMetricFiltersResponseTypeDef, None, None]:
+    ) -> Iterator[DescribeMetricFiltersResponseTypeDef]:
         """
-        [DescribeMetricFilters.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.4/reference/services/logs.html#CloudWatchLogs.Paginator.DescribeMetricFilters.paginate)
+        [DescribeMetricFilters.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/logs.html#CloudWatchLogs.Paginator.DescribeMetricFilters.paginate)
         """
 
 
 class DescribeQueriesPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeQueries documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.4/reference/services/logs.html#CloudWatchLogs.Paginator.DescribeQueries)
+    [Paginator.DescribeQueries documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/logs.html#CloudWatchLogs.Paginator.DescribeQueries)
     """
 
     def paginate(
@@ -154,28 +158,28 @@ class DescribeQueriesPaginator(Boto3Paginator):
         logGroupName: str = None,
         status: Literal["Scheduled", "Running", "Complete", "Failed", "Cancelled"] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DescribeQueriesResponseTypeDef, None, None]:
+    ) -> Iterator[DescribeQueriesResponseTypeDef]:
         """
-        [DescribeQueries.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.4/reference/services/logs.html#CloudWatchLogs.Paginator.DescribeQueries.paginate)
+        [DescribeQueries.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/logs.html#CloudWatchLogs.Paginator.DescribeQueries.paginate)
         """
 
 
 class DescribeResourcePoliciesPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeResourcePolicies documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.4/reference/services/logs.html#CloudWatchLogs.Paginator.DescribeResourcePolicies)
+    [Paginator.DescribeResourcePolicies documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/logs.html#CloudWatchLogs.Paginator.DescribeResourcePolicies)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[DescribeResourcePoliciesResponseTypeDef, None, None]:
+    ) -> Iterator[DescribeResourcePoliciesResponseTypeDef]:
         """
-        [DescribeResourcePolicies.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.4/reference/services/logs.html#CloudWatchLogs.Paginator.DescribeResourcePolicies.paginate)
+        [DescribeResourcePolicies.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/logs.html#CloudWatchLogs.Paginator.DescribeResourcePolicies.paginate)
         """
 
 
 class DescribeSubscriptionFiltersPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeSubscriptionFilters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.4/reference/services/logs.html#CloudWatchLogs.Paginator.DescribeSubscriptionFilters)
+    [Paginator.DescribeSubscriptionFilters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/logs.html#CloudWatchLogs.Paginator.DescribeSubscriptionFilters)
     """
 
     def paginate(
@@ -183,15 +187,15 @@ class DescribeSubscriptionFiltersPaginator(Boto3Paginator):
         logGroupName: str,
         filterNamePrefix: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DescribeSubscriptionFiltersResponseTypeDef, None, None]:
+    ) -> Iterator[DescribeSubscriptionFiltersResponseTypeDef]:
         """
-        [DescribeSubscriptionFilters.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.4/reference/services/logs.html#CloudWatchLogs.Paginator.DescribeSubscriptionFilters.paginate)
+        [DescribeSubscriptionFilters.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/logs.html#CloudWatchLogs.Paginator.DescribeSubscriptionFilters.paginate)
         """
 
 
 class FilterLogEventsPaginator(Boto3Paginator):
     """
-    [Paginator.FilterLogEvents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.4/reference/services/logs.html#CloudWatchLogs.Paginator.FilterLogEvents)
+    [Paginator.FilterLogEvents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/logs.html#CloudWatchLogs.Paginator.FilterLogEvents)
     """
 
     def paginate(
@@ -204,7 +208,7 @@ class FilterLogEventsPaginator(Boto3Paginator):
         filterPattern: str = None,
         interleaved: bool = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[FilterLogEventsResponseTypeDef, None, None]:
+    ) -> Iterator[FilterLogEventsResponseTypeDef]:
         """
-        [FilterLogEvents.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.4/reference/services/logs.html#CloudWatchLogs.Paginator.FilterLogEvents.paginate)
+        [FilterLogEvents.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/logs.html#CloudWatchLogs.Paginator.FilterLogEvents.paginate)
         """
